@@ -1,4 +1,7 @@
 package Dist::Zilla::Plugin::Documentation::SQL;
+{
+  $Dist::Zilla::Plugin::Documentation::SQL::VERSION = '0.03';
+}
 
 # ABSTRACT: Create a file gathering all =sql commands
 
@@ -9,6 +12,7 @@ use warnings;
 use Path::Class;
 use Pod::Elemental;
 use Pod::Elemental::Element::Nested;
+use Pod::Weaver::Section::SQL 0.03;
 use Moose;
 
 with qw/
@@ -54,8 +58,12 @@ sub munge_files {
 
                 # Remove the '=sql' command part
                 map {
+                    my $formatter = Pod::Weaver::Section::SQL->new(
+                        plugin_name => 'Pod::Weaver::Section::SQL',
+                        weaver => bless({}, 'Pod::Weaver'),
+                    );
                     Pod::Elemental::Element::Pod5::Ordinary->new(
-                        content => $_->content )
+                        content => $formatter->format_sql($_->content) )
                   }
 
                   # Keep only sql commands content
@@ -68,6 +76,21 @@ sub munge_files {
 
         if ( @{ $file_section->children } ) {
 
+            my $file_package = $file->name;
+            $file_package =~ s,lib/,,g;
+            $file_package =~ s,\.pm,,g;
+            $file_package =~ s,/,::,g;
+
+            # Push front of children a link to the file
+            $file_section->children(
+                [
+                    Pod::Elemental::Element::Pod5::Ordinary->new(
+                        content => "L<$file_package>",
+                    ),
+                    @{ $file_section->children }
+                ]
+            );
+
             # Push-back
             $document->children( [ @{ $document->children }, $file_section ] );
         }
@@ -95,7 +118,7 @@ Dist::Zilla::Plugin::Documentation::SQL - Create a file gathering all =sql comma
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
